# deriva-qt

Graphical User Interface tools for DERIVA using PyQt5

* Authentication Agent
* File Uploader

## Installation
### Windows / MacOS
Windows and MacOS users can download prebuilt bundles which include all
dependencies [here](https://github.com/informatics-isi-edu/deriva-client-bundle/releases).
Download the appropriate file for your OS.

## Install from source

See the source installation instructions [here](https://github.com/informatics-isi-edu/deriva-client-bundle/blob/master/README.md).


## User Instructions 

### deriva-auth

At the command-line, execute deriva-auth to set up credentials with deriva server.

```
deriva-auth
```


Links:
* [Build status](http://buildbot.isrd.isi.edu/)
* [Downloads](http://buildbot.isrd.isi.edu/~buildbot/deriva-client-bundle/)
